@@ -396,7 +396,7 @@ void KNutAnalog::paintBackGround ( void ) {
   m_scaleLayerBig->fill( this,0,0); //color if background
 
   paint.begin ( m_scaleLayerBig );
-  paint.setBackgroundMode(Qt::OpaqueMode);
+  paint.setBackgroundMode(TQt::OpaqueMode);
   paint.setBackgroundColor(backgroundColor());
   paintPartOfCircle(&paint, m_centerX*3, m_centerY*3,m_widthOfScale*3);  //CMK pro inter
   paintScale(&paint, m_centerX*3, m_centerY*3,m_widthOfScale*3);  // Scale
@@ -442,7 +442,7 @@ void KNutAnalog::paintPointerSlowly ( double position, int centerX , int centerY
 
   m_pointerLayerBig->fill( TQt::white );  //color if beckground
   paint.begin( m_pointerLayerBig ); // paints of pointer
-  paint.setBackgroundMode(Qt::TransparentMode);
+  paint.setBackgroundMode(TQt::TransparentMode);
 
   paint.setBrush( m_pointerColor ); // sets color
   paint.setPen ( m_pointerColor );
@@ -479,7 +479,7 @@ void KNutAnalog::paintPointerFastly (double position) {
   //m_pointerMutex.lock();
   m_pointerLayerSmall->fill( TQt::white );  //background color
   paint.begin( m_pointerLayerSmall ); // kreslime na plochu rucicky
-  paint.setBackgroundMode(Qt::TransparentMode);
+  paint.setBackgroundMode(TQt::TransparentMode);
   paintValueOfPointer ( &paint, m_valueOfPointer);
 
 
