@@ -39,7 +39,7 @@ KNutNet::KNutNet (const TQString upsAddress, const TQString upsName, const unsig
         : TQObject(), m_upsAddress(upsAddress), m_upsName(upsName), m_countRepeat(countRepeat), m_port(port), m_delay(delay)  {
 
 
-//qDebug ("KNutNet::KNutNet");
+//tqDebug ("KNutNet::KNutNet");
 
   m_state = Idle;  //idle is value
   m_numberVars = 0;
@@ -53,15 +53,15 @@ KNutNet::KNutNet (const TQString upsAddress, const TQString upsName, const unsig
   m_description = false; // popis neni natazen  - description is not loaded
 
   m_unConnectTimer = new TQTimer( this );
-  connect( m_unConnectTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotTimerReconnect()) );
+  connect( m_unConnectTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotTimerReconnect()) );
 
   m_error = NoError;
 
   m_commandSocket = new TQSocket( this );
-  connect( m_commandSocket, TQT_SIGNAL( hostFound()),this, TQT_SLOT( slotHostFound()));
-  connect( m_commandSocket, TQT_SIGNAL( connected()),this,TQT_SLOT( slotConnected()));
-  connect( m_commandSocket, TQT_SIGNAL( connectionClosed()),this, TQT_SLOT( slotConnectionClosed()));
-  connect( m_commandSocket, TQT_SIGNAL( error(int)),this, TQT_SLOT( slotConnectionError(int)));
+  connect( m_commandSocket, TQ_SIGNAL( hostFound()),this, TQ_SLOT( slotHostFound()));
+  connect( m_commandSocket, TQ_SIGNAL( connected()),this,TQ_SLOT( slotConnected()));
+  connect( m_commandSocket, TQ_SIGNAL( connectionClosed()),this, TQ_SLOT( slotConnectionClosed()));
+  connect( m_commandSocket, TQ_SIGNAL( error(int)),this, TQ_SLOT( slotConnectionError(int)));
   }
 
 
@@ -97,7 +97,7 @@ void KNutNet::close (void) {
     m_commandSocket->close(); // closes the socket
 
     if ( m_commandSocket->state() == TQSocket::Closing ) {
-      connect( m_commandSocket, TQT_SIGNAL(delayedCloseFinished()),this,TQT_SLOT(slotClosed()) );
+      connect( m_commandSocket, TQ_SIGNAL(delayedCloseFinished()),this,TQ_SLOT(slotClosed()) );
       }
     else {
       slotClosed();
@@ -107,7 +107,7 @@ void KNutNet::close (void) {
 
 void KNutNet::slotClosed (void) {
 
-  disconnect( m_commandSocket,TQT_SIGNAL(delayedCloseFinished()),this, TQT_SLOT(slotClosed()) );
+  disconnect( m_commandSocket,TQ_SIGNAL(delayedCloseFinished()),this, TQ_SLOT(slotClosed()) );
   m_state = Idle;
   }
 
@@ -446,8 +446,8 @@ TQString KNutNet::readEnumValueVar (const TQString name, const int valueNumber)
 
   m_error =0;
   if (m_state == Connected) {
-//    #if defined  (KDE_VERSION_MAJOR)
-//      #if KDE_VERSION_MAJOR >= 3
+//    #if defined  (TDE_VERSION_MAJOR)
+//      #if TDE_VERSION_MAJOR >= 3
         TQValueVector<upsVarDef>::const_iterator it;
 //      #else
 //        TQValueList<upsVar>::ConstIterator it;
@@ -966,8 +966,8 @@ void KNutNet::upsSetType (struct upsVarDef& upsVar, const TQString name, const T
 
 
 void KNutNet::deleteVars (void) {
-//  #if defined  (KDE_VERSION_MAJOR)
-//    #if KDE_VERSION_MAJOR >= 3
+//  #if defined  (TDE_VERSION_MAJOR)
+//    #if TDE_VERSION_MAJOR >= 3
       TQValueVector<upsVarDef>::iterator it;
 //    #else
 //      TQValueList<upsVar>::Iterator it;
@@ -1023,7 +1023,7 @@ int KNutNet::getDescription1 (bool always) {
      TQValueVector<upsICommDef>::iterator itc;
      for (itv = m_listVars.begin(); itv != m_listVars.end(); itv++) {
       //nacteme promenou
-      inBuffer = "VARDESC " + (*itv).upsVarName + "\n";
+      inBuffer = "VARDESC " + (*itv).upsVarName.local8Bit() + "\n";
       if ((m_error = newDescription (inBuffer, (*itv).upsDescription))) {
         //netMutex.unlock();
 //        netMutex=false;
@@ -1032,7 +1032,7 @@ int KNutNet::getDescription1 (bool always) {
       }
     for (itc = m_listIComms.begin(); itc != m_listIComms.end(); itc++) {
       //nacteme promenou
-      inBuffer = "INSTCMDDESC "+(*itc).upsCommName+"\n";
+      inBuffer = "INSTCMDDESC "+(*itc).upsCommName.local8Bit()+"\n";
       if ((m_error = newDescription (inBuffer, (*itc).upsDescription))) {
         //netMutex.unlock();
         //netMutex=false;
@@ -1062,7 +1062,7 @@ int KNutNet::getDescription2 (bool always) {
      TQValueVector<upsICommDef>::iterator itc;
      for (itv = m_listVars.begin(); itv != m_listVars.end(); itv++) {
       //nacteme promenou
-      inBuffer = "GET DESC " + m_upsName + " " + (*itv).upsVarName+"\n";
+      inBuffer = "GET DESC " + m_upsName.local8Bit() + " " + (*itv).upsVarName.local8Bit()+"\n";
 
       if (!(m_error=getUpsData (inBuffer,outBuffer))) {
         outBuffer=outBuffer.stripWhiteSpace ();
@@ -1091,7 +1091,7 @@ int KNutNet::getDescription2 (bool always) {
       }
     for (itc = m_listIComms.begin(); itc != m_listIComms.end(); itc++) {
       //nacteme promenou
-      inBuffer = "GET CMDDESC " + m_upsName + " " + (*itc).upsCommName+"\n";
+      inBuffer = "GET CMDDESC " + m_upsName.local8Bit() + " " + (*itc).upsCommName.local8Bit()+"\n";
       if (!(m_error=getUpsData (inBuffer,outBuffer))) {
         outBuffer=outBuffer.stripWhiteSpace ();
         if ( !outBuffer.isEmpty() ) {
@@ -1136,7 +1136,7 @@ int KNutNet::getUpsVars1 ( void) {
   // init vars and lists
   if (!m_upsName.isEmpty()) { // pokud upsName neni je vzdy nastaveno na null
     inBuffer="LISTVARS ";
-    inBuffer.append(m_upsName);
+    inBuffer.append(m_upsName.local8Bit());
     inBuffer.append("\n");
     }
   else inBuffer ="LISTVARS\n";
@@ -1184,7 +1184,7 @@ int KNutNet::getUpsVars1 ( void) {
   // *********** RW VARIABLES
   if (!m_upsName.isEmpty()) { // pokud upsName neni je vzdy nastaveno na null
     inBuffer="LISTRW ";
-    inBuffer.append(m_upsName);
+    inBuffer.append(m_upsName.local8Bit());
     inBuffer.append("\n");
     }
   else inBuffer ="LISTRW\n";
@@ -1220,10 +1220,10 @@ int KNutNet::getUpsVars1 ( void) {
           // Zpracujeme polozku v tabulce
           // zjistime informaci o promene
           inBuffer="VARTYPE ";
-          inBuffer.append(word);
+          inBuffer.append(word.local8Bit());
           if (!m_upsName.isEmpty()) {
             inBuffer.append("@"); // pokud upsName neni je vzdy nastaveno na null
-            inBuffer.append(m_upsName);
+            inBuffer.append(m_upsName.local8Bit());
             }
           inBuffer.append("\n");
           if (!(m_error=getUpsData (inBuffer,varOutBuffer))) {
@@ -1271,11 +1271,11 @@ int KNutNet::getUpsVars1 ( void) {
           if (!valueType) {
           // nacteme enum hodnoty
             inBuffer="ENUM ";
-            inBuffer.append(word);
+            inBuffer.append(word.local8Bit());
             // pokud existuje pridame jmeno UPS-ky
             if (!m_upsName.isEmpty()) {
               inBuffer.append("@");
-              inBuffer.append(m_upsName);
+              inBuffer.append(m_upsName.local8Bit());
               }
             inBuffer.append("\n");
             if (!(m_error=getUpsData (inBuffer,varOutBuffer,"END\n"))) {
@@ -1343,7 +1343,7 @@ int KNutNet::getUpsVars1 ( void) {
   // *************** INSTANT COMMAND
   if (!m_upsName.isEmpty()) { // pokud upsName neni je vzdy nastaveno na null
     inBuffer="LISTINSTCMD ";
-    inBuffer.append(m_upsName);
+    inBuffer.append(m_upsName.local8Bit());
     inBuffer.append("\n");
     }
   else inBuffer ="LISTINSTCMD\n";
@@ -1403,7 +1403,7 @@ int KNutNet::getUpsVars2 ( void) {
   int varMax=0;
 
   TQValueVector<TQString>* enumString=0;
-  inBuffer = "LIST VAR " + m_upsName + "\n";
+  inBuffer = "LIST VAR " + m_upsName.local8Bit() + "\n";
   if (!(m_error=getUpsData (inBuffer,outBuffer,"END LIST VAR"))) {
     TQString inLine, upsNameRet, varName, varNameRet, value;
     bool beginList = false;
@@ -1420,7 +1420,7 @@ int KNutNet::getUpsVars2 ( void) {
            upsSetType(upsVar, varName, value);
 
            if (varName == "ups.status") genStatusFlags(value);
-           inBuffer = "GET TYPE " + m_upsName + " " + varName +"\n";
+           inBuffer = "GET TYPE " + m_upsName.local8Bit() + " " + varName.local8Bit() +"\n";
            if (!(m_error=getUpsData (inBuffer,varOutBuffer))) {
              key = parseLine (varOutBuffer, upsNameRet, varNameRet, value, typeValue, lenString);
              switch (key) {
@@ -1431,7 +1431,7 @@ int KNutNet::getUpsVars2 ( void) {
                   if (typeValue & ENUM_FLAG) {
                     upsVar.upsValueType=false;
                     // nacteme enumValues
-                    inBuffer = "LIST ENUM " + m_upsName + " " + varName +"\n";
+                    inBuffer = "LIST ENUM " + m_upsName.local8Bit() + " " + varName.local8Bit() +"\n";
                     if (!(m_error=getUpsData (inBuffer,varOutBuffer,"END LIST ENUM"))) {
                       bool beginEnumList = false;
                       TQTextIStream varInputStream(&varOutBuffer);
@@ -1500,7 +1500,7 @@ int KNutNet::getUpsVars2 ( void) {
   else { return m_error; }
   // INSTANT COMMANDS
 
-  inBuffer = "LIST CMD " + m_upsName + "\n";
+  inBuffer = "LIST CMD " + m_upsName.local8Bit() + "\n";
   if (!(m_error=getUpsData (inBuffer,outBuffer,"END LIST CMD"))) {
 
     TQString inLine, upsNameRet, varName, value;
@@ -1562,10 +1562,10 @@ int KNutNet::getUpsValues1 (const bool allVars ) {// allVars = true vse; allVars
       if ((allVars) || ((*it).upsVarActivate)) {
         //nacteme promenou
         inBuffer = "REQ ";
-        inBuffer.append((*it).upsVarName);
+        inBuffer.append((*it).upsVarName.local8Bit());
         if (!m_upsName.isEmpty()) { // pokud upsName neni je vzdy nastaveno na null
           inBuffer.append("@");
-          inBuffer.append(m_upsName);
+          inBuffer.append(m_upsName.local8Bit());
           }
         inBuffer.append("\n");
 //        if (!(error=getUpsData (inBuffer,outBuffer))) {
@@ -1660,7 +1660,7 @@ int KNutNet::getUpsValues2 (const bool allVars ) {// allVars = true vse; allVars
     numberVar++;
     if ((allVars) || ((*it).upsVarActivate)) {
       //reads variable
-      inBuffer = "GET VAR "+m_upsName+" "+(*it).upsVarName+"\n";
+      inBuffer = "GET VAR "+m_upsName.local8Bit()+" "+(*it).upsVarName.local8Bit()+"\n";
 //      if (!(error=getUpsData (inBuffer,outBuffer))) {
       m_error=getUpsData (inBuffer,outBuffer);
       // when outBuffer is empty sends and reads date again, but only the only time
@@ -1712,17 +1712,24 @@ int KNutNet::sendComm (const TQString command, const TQString arg1, const TQStri
 
   switch (m_nutProtocol) {
     case 1:
-      inBuffer=command + " " + arg1;
-      if (useUpsName && (!m_upsName.isEmpty())) // pokud upsName neni je vzdy prazdne
-        inBuffer += "@"+m_upsName;
-   if (!arg2.isEmpty()) inBuffer += " " + arg2;
-    break;
+      inBuffer=command.local8Bit() + " " + arg1.local8Bit();
+      if (useUpsName && (!m_upsName.isEmpty())) { // pokud upsName neni je vzdy prazdne
+        inBuffer += "@"+m_upsName.local8Bit();
+      }
+      if (!arg2.isEmpty()) {
+        inBuffer += " " + arg2.local8Bit();
+      }
+      break;
     case 2:
-    inBuffer = command + " ";
-    if (useUpsName) inBuffer += m_upsName + " ";
-    inBuffer.append(arg1);
-   if (!arg2.isEmpty()) inBuffer += " \"" + arg2 +"\"";
-   break;
+      inBuffer = command.local8Bit() + " ";
+      if (useUpsName) {
+        inBuffer += m_upsName.local8Bit() + " ";
+      }
+      inBuffer.append(arg1.local8Bit());
+      if (!arg2.isEmpty()) {
+        inBuffer += " \"" + arg2.local8Bit() +"\"";
+      }
+      break;
     }
   inBuffer.append("\n");
 
@@ -1819,7 +1826,7 @@ int KNutNet::upsOldTranslateError (const TQString string) {
 
 void KNutNet::slotConnectionError(int error) {
 //std::cout << "--KNutNet::slotConnectionError"  << std::endl;
-//qDebug ("--KNutNet::slotConnectionError");
+//tqDebug ("--KNutNet::slotConnectionError");
 
   m_state = ConnectError;
   m_unConnectTimer->stop();
@@ -1833,13 +1840,13 @@ void KNutNet::slotConnectionError(int error) {
     if (m_firstConnect) {
       if (m_numberConnection < m_countRepeat) {
         m_numberConnection++;
-//    qDebug ("--KNutNet:: connect error - try connect on next time");
+//    tqDebug ("--KNutNet:: connect error - try connect on next time");
         m_unConnectTimer->start( m_delay, TRUE );
         }
       else  {
         // i don't connect server
         error=CantConnect;
-//        qDebug("--KNutNet::emit - connection error ");
+//        tqDebug("--KNutNet::emit - connection error ");
         emit connectionError(error);
         return;
         }
@@ -1847,7 +1854,7 @@ void KNutNet::slotConnectionError(int error) {
     else {
       // connecting is down, try repeated connection
 
-//    qDebug ("--KNutNet::no first connect connection error ");
+//    tqDebug ("--KNutNet::no first connect connection error ");
       m_unConnectTimer->start( m_delay, TRUE );
       }
     return;
