@@ -56,7 +56,7 @@ class TQString;
 */
 class KNutPrintUpsVar : public KDialogBase  {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
