@@ -116,7 +116,7 @@ KNutRWVar::KNutRWVar(TQString* userName, TQString* userPassword, const TQString
       m_valueVarLine->show();
       m_upsValueType=true;
       }
-    connect (m_rWVarBox,TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotChangeVar(int)));
+    connect (m_rWVarBox,TQ_SIGNAL(activated(int)),this,TQ_SLOT(slotChangeVar(int)));
     }
   }
 
