@@ -38,7 +38,7 @@ class TQGridLayout;
  * @version 0.2
 */
 class KNutRWVar : public KDialogBase  {
-  Q_OBJECT
+  TQ_OBJECT
   
   public: 
 /**
@@ -106,7 +106,7 @@ class KNutRWVar : public KDialogBase  {
  * Find asked item in box
  * Since at version 3.0.0 is not needed. 
  * Najde pozadovanou polozku v boxu.
- * Ve verzi qt > 3.0.0 neni potreba.
+ * Ve verzi TQt > 3.0.0 neni potreba.
  */
 int findItem(const KComboBox *myBox ,const TQString text);
 
